==> de.flapdoodle.embed.mongo-2.0.3-sources.jar: de/flapdoodle/embed/mongo/config/MongoShellConfigBuilder.java <==
/**
 * Copyright (C) 2011
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,Archimedes Trajano	(trajano@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.mongo.config;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import de.flapdoodle.embed.mongo.Command;
import de.flapdoodle.embed.mongo.distribution.IFeatureAwareVersion;
import de.flapdoodle.embed.process.builder.TypedProperty;

public class MongoShellConfigBuilder extends AbstractMongoConfigBuilder<IMongoShellConfig> {

	protected static final TypedProperty<String> JS_SCRIPT = TypedProperty.with("scriptName", String.class);
	protected static final TypedProperty<List> JS_SCRIPT_PARAMETERS = TypedProperty.with("parameters", List.class);

	public MongoShellConfigBuilder() throws IOException {
		property(PID_FILE).setDefault("mongo.pid");
	}

	public MongoShellConfigBuilder version(IFeatureAwareVersion version) {
		version().set(version);
		return this;
	}

	public MongoShellConfigBuilder timeout(Timeout timeout) {
		timeout().set(timeout);
		return this;
	}

	public MongoShellConfigBuilder username(String username) {
		username().set(username);
		return this;
	}

	public MongoShellConfigBuilder password(String password) {
		password().set(password);
		return this;
	}

	public MongoShellConfigBuilder net(Net net) {
		net().set(net);
		return this;
	}

	public MongoShellConfigBuilder dbName(String dbName) {
		dbName().set(dbName);
		return this;
	}

	public MongoShellConfigBuilder cmdOptions(IMongoCmdOptions cmdOptions) {
		cmdOptions().set(cmdOptions);
		return this;
	}

	public MongoShellConfigBuilder scriptName(String scriptName) {
		set(JS_SCRIPT, scriptName);
		return this;
	}

	public MongoShellConfigBuilder parameters(String... parameters) {
		return parameters(Arrays.asList(parameters));
	}

	public MongoShellConfigBuilder parameters(List<String> parameters) {
		set(JS_SCRIPT_PARAMETERS, parameters);
		return this;
	}

	@Override
	public IMongoShellConfig build() {
		IFeatureAwareVersion version = version().get();
		Net net = net().get();
		Timeout timeout = timeout().get();
		IMongoCmdOptions cmdOptions=get(CMD_OPTIONS);
		String pidFile = get(PID_FILE);

		String name = get(JS_SCRIPT,null);
		List<String> parameters = get(JS_SCRIPT_PARAMETERS,new ArrayList<String>());
		if ((name==null) && (parameters.isEmpty())) {
			throw new RuntimeException("you must set parameters or scriptName");
		}

		return new ImmutableMongoShellConfig(version, net, timeout, cmdOptions, pidFile, name,
					username().get(), password().get(), dbName().get(), parameters);
	}

	static class ImmutableMongoShellConfig extends ImmutableMongoConfig implements IMongoShellConfig {

		private final String _name;
		private final String _dbname;
		private final List<String> _parameters;

		public ImmutableMongoShellConfig(IFeatureAwareVersion version, Net net, Timeout timeout,
											IMongoCmdOptions cmdOptions, String pidFile,
											String scriptName, String username, String password, String dbName,
											List<String> parameters) {
 			super(new SupportConfig(Command.Mongo), version, net, username, password, timeout, cmdOptions, pidFile);
 			this._dbname = dbName;
			this._name = scriptName;
			this._parameters = Collections.unmodifiableList(new ArrayList<>(parameters));
		}

		@Override
		public List<String> getScriptParameters() {
			return _parameters;
		}

		@Override
		public String getScriptName() {
			return _name;
 		}

 		@Override
 		public String getDbName() {
 			return _dbname;
		}

	}
}

==> de.flapdoodle.embed.mongo-2.2.0-sources.jar: de/flapdoodle/embed/mongo/config/MongoShellConfigBuilder.java <==
/**
 * Copyright (C) 2011
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,Archimedes Trajano	(trajano@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.mongo.config;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import de.flapdoodle.embed.mongo.Command;
import de.flapdoodle.embed.mongo.distribution.IFeatureAwareVersion;
import de.flapdoodle.embed.process.builder.TypedProperty;

public class MongoShellConfigBuilder extends AbstractMongoConfigBuilder<IMongoShellConfig> {

	protected static final TypedProperty<String> JS_SCRIPT = TypedProperty.with("scriptName", String.class);
	protected static final TypedProperty<List> JS_SCRIPT_PARAMETERS = TypedProperty.with("parameters", List.class);

	public MongoShellConfigBuilder() throws IOException {
		property(PID_FILE).setDefault("mongo.pid");
	}

	public MongoShellConfigBuilder version(IFeatureAwareVersion version) {
		version().set(version);
		return this;
	}

	public MongoShellConfigBuilder timeout(Timeout timeout) {
		timeout().set(timeout);
		return this;
	}

	public MongoShellConfigBuilder username(String username) {
		username().set(username);
		return this;
	}

	public MongoShellConfigBuilder password(String password) {
		password().set(password);
		return this;
	}

	public MongoShellConfigBuilder net(Net net) {
		net().set(net);
		return this;
	}

	public MongoShellConfigBuilder dbName(String dbName) {
		dbName().set(dbName);
		return this;
	}

	public MongoShellConfigBuilder cmdOptions(IMongoCmdOptions cmdOptions) {
		cmdOptions().set(cmdOptions);
		return this;
	}

	public MongoShellConfigBuilder scriptName(String scriptName) {
		set(JS_SCRIPT, scriptName);
		return this;
	}

	public MongoShellConfigBuilder parameters(String... parameters) {
		return parameters(Arrays.asList(parameters));
	}

	public MongoShellConfigBuilder parameters(List<String> parameters) {
		set(JS_SCRIPT_PARAMETERS, parameters);
		return this;
	}

	public MongoShellConfigBuilder stopTimeoutInMillis(long timeout) {
		stopTimeout().set(timeout);
		return this;
	}

	@Override
	public IMongoShellConfig build() {
		IFeatureAwareVersion version = version().get();
		Net net = net().get();
		Timeout timeout = timeout().get();
		IMongoCmdOptions cmdOptions=get(CMD_OPTIONS);
		String pidFile = get(PID_FILE);

		String name = get(JS_SCRIPT,null);
		List<String> parameters = get(JS_SCRIPT_PARAMETERS,new ArrayList<String>());
		if ((name==null) && (parameters.isEmpty())) {
			throw new RuntimeException("you must set parameters or scriptName");
		}
		Long stopTimeoutInMillis = get(STOP_TIMEOUT_MILLIS);


		return new ImmutableMongoShellConfig(version, net, timeout, cmdOptions, pidFile, name,
					username().get(), password().get(), dbName().get(), stopTimeoutInMillis, parameters);
	}

	static class ImmutableMongoShellConfig extends ImmutableMongoConfig implements IMongoShellConfig {

		private final String _name;
		private final String _dbname;
		private final List<String> _parameters;

		public ImmutableMongoShellConfig(IFeatureAwareVersion version, Net net, Timeout timeout,
										 IMongoCmdOptions cmdOptions, String pidFile,
										 String scriptName, String username, String password, String dbName,
										 Long stopTimeoutInMillis, List<String> parameters) {
 			super(new SupportConfig(Command.Mongo, stopTimeoutInMillis), version, net, username, password, timeout, cmdOptions, pidFile);
 			this._dbname = dbName;
			this._name = scriptName;
			this._parameters = Collections.unmodifiableList(new ArrayList<>(parameters));
		}

		@Override
		public List<String> getScriptParameters() {
			return _parameters;
		}

		@Override
		public String getScriptName() {
			return _name;
 		}

 		@Override
 		public String getDbName() {
 			return _dbname;
		}

	}
}
